Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(615)

Unified Diff: tools/testing/dart/drt_updater.dart

Issue 15755017: Switch from DRT to content shell. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/get_archive.py ('k') | tools/testing/dart/test_options.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/testing/dart/drt_updater.dart
diff --git a/tools/testing/dart/drt_updater.dart b/tools/testing/dart/drt_updater.dart
index 67e1716c454f2be77497ffa994bf79b8e6c3c6e5..ea86b4aad1f99f4d5cd8940ab3f956f842f2fcd1 100644
--- a/tools/testing/dart/drt_updater.dart
+++ b/tools/testing/dart/drt_updater.dart
@@ -2,6 +2,8 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
+// TODO(antonm): rename to something like test_runner_updater.
+
library drt_updater;
import "dart:async";
@@ -60,18 +62,18 @@ class _DartiumUpdater {
}
}
-_DartiumUpdater _dumpRenderTreeUpdater;
+_DartiumUpdater _contentShellUpdater;
_DartiumUpdater _dartiumUpdater;
_DartiumUpdater runtimeUpdater(Map configuration) {
String runtime = configuration['runtime'];
if (runtime == 'drt' && configuration['drt'] == '') {
- // Download the default DumpRenderTree from Google Storage.
- if (_dumpRenderTreeUpdater == null) {
- _dumpRenderTreeUpdater = new _DartiumUpdater('DumpRenderTree',
- 'get_archive.py', 'drt');
+ // Download the default content shell from Google Storage.
+ if (_contentShellUpdater == null) {
+ _contentShellUpdater = new _DartiumUpdater('Content Shell',
+ 'get_archive.py', 'drt');
}
- return _dumpRenderTreeUpdater;
+ return _contentShellUpdater;
} else if (runtime == 'dartium' && configuration['dartium'] == '') {
// Download the default Dartium from Google Storage.
if (_dartiumUpdater == null) {
« no previous file with comments | « tools/get_archive.py ('k') | tools/testing/dart/test_options.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698